@@ -153,7 +153,8 @@ def intersect_mesh_lines(mesh, start_points, end_points, max_dist=None, parallel
         int_list = []
         for ept in end_points:
             lin = rg.Line(pt, ept)
-            is_clear = 1 if rg.Intersect.Intersection.MeshLine(mesh, lin)[1] is None else 0
+            int_obj = rg.Intersect.Intersection.MeshLine(mesh, lin)
+            is_clear = 1 if None in int_obj or len(int_obj) == 0 else 0
             int_list.append(is_clear)
         int_matrix[i] = int_list
 
@@ -166,8 +167,8 @@ def intersect_mesh_lines(mesh, start_points, end_points, max_dist=None, parallel
             if lin.Length > max_dist:
                 int_list.append(0)
             else:
-                is_clear = 1 if rg.Intersect.Intersection.MeshLine(mesh, lin)[1] \
-                    is None else 0
+                int_obj = rg.Intersect.Intersection.MeshLine(mesh, lin)
+                is_clear = 1 if None in int_obj or len(int_obj) == 0 else 0
                 int_list.append(is_clear)
         int_matrix[i] = int_list
 
