@@ -5,6 +5,7 @@ import xml.etree.ElementTree
 
 try:
     from ladybug.futil import nukedir, copy_file_tree
+    from ladybug.config import folders as lb_folders
 except ImportError as e:
     raise ImportError("Failed to import ladybug.\n{}".format(e))
 
@@ -28,8 +29,7 @@ def create_python_package_dir():
     This method works both on Windows and Mac. If the folder is not found, this
     method will create the folder.
     """
-    home_folder = os.getenv('HOME') or os.path.expanduser('~')
-    py_install = os.path.join(home_folder, 'ladybug_tools', 'python')
+    py_install = os.path.join(lb_folders.ladybug_tools_folder, 'python')
     py_path = os.path.join(py_install, 'Lib', 'site-packages') if os.name == 'nt' \
         else os.path.join(py_install, 'lib', 'python3.7', 'site-packages')
     if not os.path.isdir(py_path):
